package forms {
	import dtos.InvoiceDTO;
	import dtos.UserDTO;
	
	import events.ConditionalEvent;
	import events.GenericArrayEvent;
	
	import helpers.Constants;
	import helpers.TimeValidator;
	
	import mx.containers.Box;
	import mx.controls.Alert;
	import mx.controls.DateField;
	import mx.controls.Label;
	import mx.controls.TextInput;
	import mx.messaging.ChannelSet;
	import mx.messaging.channels.AMFChannel;
	import mx.messaging.messages.ErrorMessage;
	import mx.rpc.events.FaultEvent;
	import mx.rpc.events.ResultEvent;
	import mx.rpc.remoting.RemoteObject;
	import mx.validators.DateValidator;
	import mx.validators.NumberValidator;
	import mx.validators.Validator;
	
	import org.spicefactory.lib.logging.LogContext;
	import org.spicefactory.lib.logging.Logger;
	

	/**
	 *
	 * @author Jose
	 */
	public class InvoiceFormCodeBehind extends Box {
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var userDTO:UserDTO;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var result:Label;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var invoiceDTO:InvoiceDTO;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var invoicingService:RemoteObject;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var minStepsValidator:DateValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var tStepsValidator:NumberValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pStepsValidator:NumberValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pSurchargesValidator:NumberValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var totalStepsValidator:NumberValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pTimeOnValidator:TimeValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pCollectedValidator:NumberValidator;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var date:DateField;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var tSteps:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pSteps:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pSurcharges:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pCollected:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var pTimeOn:TextInput;
		/**
		 *
		 * @default
		 */
		public var isNewInvoice:Boolean=false;
		/**
		 *
		 * @default
		 */
		public var validatorArr=new Array();
		public var copyInvoiceDTO:InvoiceDTO;
		private var logger:Logger=LogContext.getLogger(InvoiceFormCodeBehind);

		/**
		 *
		 */
		public function InvoiceFormCodeBehind() {
			super();
		}

		/**
		 *
		 */
		public function init():void {
			validatorArr.push(minStepsValidator);
			validatorArr.push(tStepsValidator);
			validatorArr.push(pStepsValidator);
			validatorArr.push(pSurchargesValidator);
			validatorArr.push(pCollectedValidator);
			validatorArr.push(pTimeOnValidator);
			invoiceDTO=new InvoiceDTO();
		}

		/**
		 *
		 * @return
		 */
		public function validateScreen():Boolean {
			var arrayResult:Array=Validator.validateAll(validatorArr);
			return (arrayResult.length == 0);
		}

		/**
		 * Metodo que valida y lanza un evento para la busqueda de Facturas en función a los criterios de búsqueda.
		 */
		public function saveOrUpdateInvoice():void {
			if (validateScreen()) {
				var channel:AMFChannel=new AMFChannel("my-secure-amf", Constants.URI);
				var channelSet:ChannelSet=new ChannelSet();
				channelSet.addChannel(channel);
				invoicingService.channelSet=channelSet;
				if (isNaN(invoiceDTO.id)) {
					isNewInvoice=true;
					invoiceDTO.idUser=userDTO.id;
					invoicingService.insertInvoice(invoiceDTO);
				} else {
					isNewInvoice=false;
					invoicingService.updateInvoice(invoiceDTO);
				}
			}
		}

		/**
		 *
		 * @param event
		 */
		public function onResult(event:ResultEvent):void {
			cancelEdition();
		}

		/**
		 *
		 * @param event
		 */
		public function onFault(event:FaultEvent):void {
			var errorMessage:ErrorMessage=event.message as ErrorMessage;
			trace("message: " + errorMessage.rootCause.message + " codeException: " + errorMessage.rootCause.codeException);
			Alert.show(resourceManager.getString('invoicingProperties', 'error.transaction'), "Error");
		}

		/**
		 * Método que limpia el formulario 
		 */
		protected function cleanForm():void {
			trace("Init clearFilter");
			cleanValidations();
			invoiceDTO=new InvoiceDTO();
			invoiceDTO.idUser=userDTO.id;
			trace(this + " Init clearFilter");
		}

		/**
		 * Método que limpia el formulario y lo deja en el estado inicial
		 */
		public function cancelEdition():void {
			cleanValidations();
			invoiceDTO=new InvoiceDTO();
			var conditionalEvent:ConditionalEvent=new ConditionalEvent("InvoiceFormCodeBehind.cancelEdition", false);
			dispatchEvent(conditionalEvent);
		}

		/**
		 *
		 */
		public function cleanValidations():void {
			date.errorString="";
			tSteps.errorString="";
			pSteps.errorString="";
			pSurcharges.errorString="";
			pCollected.errorString="";
			pTimeOn.errorString="";
		}

		[MessageHandler(selector="InvoicingGrid.invoiceToUpdate")]
		/**
		 *
		 * @param genericArrayEvent
		 */
		public function invoiceToUpdate(genericArrayEvent:GenericArrayEvent):void {
			invoiceDTO=genericArrayEvent.collection.getItemAt(0) as InvoiceDTO;
			copyInvoiceDTO=new InvoiceDTO();
			copyInvoiceDTO.id=new Number(invoiceDTO.id.valueOf());
			copyInvoiceDTO.date=new Date(invoiceDTO.date.getTime());
			copyInvoiceDTO.tSteps=new Number(invoiceDTO.tSteps.valueOf());
			copyInvoiceDTO.pSteps=new Number(invoiceDTO.pSteps.valueOf());
			copyInvoiceDTO.pSurcharges=new Number(invoiceDTO.pSurcharges.valueOf());
			copyInvoiceDTO.pCollected=new Number(invoiceDTO.pCollected.valueOf());
			copyInvoiceDTO.pTimeOn=new String(invoiceDTO.pTimeOn.valueOf());
			copyInvoiceDTO.idUser=new Number(invoiceDTO.idUser.valueOf());
		}
	}
}
