package grids {
	import dtos.InvoiceDTO;
	import dtos.UserDTO;
	
	import events.ConditionalEvent;
	import events.GenericArrayEvent;
	
	import helpers.Constants;
	
	import mx.collections.*;
	import mx.controls.Alert;
	import mx.controls.DataGrid;
	import mx.controls.Label;
	import mx.controls.TextInput;
	import mx.controls.dataGridClasses.DataGridColumn;
	import mx.events.ListEvent;
	import mx.formatters.DateFormatter;
	import mx.messaging.ChannelSet;
	import mx.messaging.channels.AMFChannel;
	import mx.messaging.messages.ErrorMessage;
	import mx.rpc.events.FaultEvent;
	import mx.rpc.events.ResultEvent;
	import mx.rpc.remoting.RemoteObject;

	/**
	 *
	 * @author Jose
	 */
	public class InvoicingGridCodeBehind extends DataGrid {
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var userDTO:UserDTO;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var userNameTextInput:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var passwordTextInput:TextInput;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var result:Label;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var authentification:RemoteObject;
		[MessageDispatcher]
		/**
		 *
		 * @default
		 */
		public var sendMessage:Function;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var arrayGrid:ArrayCollection;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var invoicesList:ArrayCollection;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var invoicingService:RemoteObject;
		[Bindable]
		/**
		 *
		 * @default
		 */
		public var formatDateTime:DateFormatter;

		/**
		 *
		 */
		public function initData():void {
			dataProvider=new ArrayCollection();
		}

		/**
		 *
		 */
		public function init():void {
		}

		/**
		 * Metodo que valida y lanza un evento para la busqueda de proveedores en función a los criterios de búsqueda.
		 */
		[MessageHandler(selector="InvoicingFilterCodeBehind.searchInvoices")]
		/**
		 *
		 * @param genericArrayEvent
		 */
		public function searchInvoices(genericArrayEvent:GenericArrayEvent):void {
			var channel:AMFChannel=new AMFChannel("my-secure-amf", Constants.URI);
			var channelSet:ChannelSet=new ChannelSet();
			channelSet.addChannel(channel);
			invoicingService.channelSet=channelSet;
			invoicingService.filterSearch(genericArrayEvent.collection.getItemAt(0));
		}

		/**
		 *
		 * @param event
		 */
		public function onResult(event:ResultEvent):void {
			if (event.result is ArrayCollection) {
				invoicesList=event.result as ArrayCollection;
				dataProvider=invoicesList;
			}
			var conditionalEvent:ConditionalEvent=new ConditionalEvent("InvoicingGrid.isSelectedInoice", false);
			dispatchEvent(conditionalEvent);
		}

		/**
		 *
		 * @param event
		 */
		public function onFault(event:FaultEvent):void {
			var errorMessage:ErrorMessage=event.message as ErrorMessage;
			trace("message: " + errorMessage.rootCause.message + " codeException: " + errorMessage.rootCause.codeException);
			Alert.show(resourceManager.getString('invoicingProperties', 'error.transaction'), "Error");
		}

		/**
		 *
		 * @param item
		 * @param column
		 * @return
		 */
		public function getDateLabel(item:Object, column:DataGridColumn):String {
			return formatDateTime.format(item[column.dataField]);
		}

		/**
		 *
		 * @param evt
		 */
		public function handleClick(evt:ListEvent):void {
			var conditionalEvent:ConditionalEvent=new ConditionalEvent("InvoicingGrid.isSelectedInoice", true);
			dispatchEvent(conditionalEvent);
		}

		[MessageHandler(selector="HomeScreenCodeBehind.updateInvoice")]
		/**
		 *
		 * @param conditionalEvent
		 */
		public function invoiceToUpdate(conditionalEvent:ConditionalEvent):void {
			var genericArrayEvent:GenericArrayEvent=new GenericArrayEvent("InvoicingGrid.invoiceToUpdate");
			genericArrayEvent.collection.addItem(selectedItem as InvoiceDTO);
			dispatchEvent(genericArrayEvent);
		}

		[MessageHandler(selector="HomeScreenCodeBehind.deleteInvoice")]
		/**
		 *
		 * @param conditionalEvent
		 */
		public function deleteInvoice(conditionalEvent:ConditionalEvent):void {
			var channel:AMFChannel=new AMFChannel("my-secure-amf", Constants.URI);
			var channelSet:ChannelSet=new ChannelSet();
			channelSet.addChannel(channel);
			invoicingService.channelSet=channelSet;
			invoicingService.deleteInvoice(selectedItem as InvoiceDTO);
			this.dataProvider.removeItemAt(selectedIndex);
		}
	}
}
