package com.invoicing.entities;

import static javax.persistence.GenerationType.IDENTITY;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;


/**
 * The Class Invoice encapsulates model parameters of an Invoice.
 * Contains annotations for integration with Hibernate.
 * 
 * @author Jose Carlos
 */
@Entity
@Table(name = "invoice", catalog = "invoicing")
public class Invoice {

	/** The id. */
	@Id
	@GeneratedValue(strategy = IDENTITY)
	@Column(name = "ID", unique = true, nullable = false)
	private Integer id;

	/** The date. */
	@Temporal(TemporalType.DATE)
	@Column(name = "DATE", nullable = false, length = 10)
	private Date date;

	/** The t steps. */
	@Column(name = "T_STEPS", nullable = false)
	private Integer tSteps;

	/** The p steps. */
	@Column(name = "P_STEPS", nullable = false)
	private Integer pSteps;

	/** The p surcharges. */
	@Column(name = "P_SURCHARGES", nullable = false)
	private Integer pSurcharges;

	/** The p collected. */
	@Column(name = "P_COLLECTED", nullable = false, precision = 2)
	private Integer pCollected;

	/** The p time on. */
	@Column(name = "P_TIME_ON", nullable = false)
	private String pTimeOn;

	/** The user. */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "USER_ID", nullable = false)
	private User user;

	/**
	 * Instantiates a new invoice.
	 */
	public Invoice() {
	}

	/**
	 * Instantiates a new invoice.
	 * 
	 * @param date
	 *            the date
	 * @param tSteps
	 *            the t steps
	 * @param pSteps
	 *            the steps
	 * @param pSurcharges
	 *            the surcharges
	 * @param pCollected
	 *            the collected
	 * @param pTimeOn
	 *            the time on
	 * @param user
	 *            the user
	 */
	public Invoice(Date date, Integer tSteps, Integer pSteps,
			Integer pSurcharges, Integer pCollected, String pTimeOn, User user) {
		super();
		this.date = date;
		this.tSteps = tSteps;
		this.pSteps = pSteps;
		this.pSurcharges = pSurcharges;
		this.pCollected = pCollected;
		this.pTimeOn = pTimeOn;
		this.user = user;
	}

	/**
	 * Gets the id.
	 * 
	 * @return the id
	 */
	public Integer getId() {
		return id;
	}

	/**
	 * Sets the id.
	 * 
	 * @param id
	 *            the new id
	 */
	public void setId(Integer id) {
		this.id = id;
	}

	/**
	 * Gets the date.
	 * 
	 * @return the date
	 */
	public Date getDate() {
		return date;
	}

	/**
	 * Sets the date.
	 * 
	 * @param date
	 *            the new date
	 */
	public void setDate(Date date) {
		this.date = date;
	}

	/**
	 * Gets the t steps.
	 * 
	 * @return the t steps
	 */
	public Integer gettSteps() {
		return tSteps;
	}

	/**
	 * Sets the t steps.
	 * 
	 * @param tSteps
	 *            the new t steps
	 */
	public void settSteps(Integer tSteps) {
		this.tSteps = tSteps;
	}

	/**
	 * Gets the p steps.
	 * 
	 * @return the p steps
	 */
	public Integer getpSteps() {
		return pSteps;
	}

	/**
	 * Sets the p steps.
	 * 
	 * @param pSteps
	 *            the new p steps
	 */
	public void setpSteps(Integer pSteps) {
		this.pSteps = pSteps;
	}

	/**
	 * Gets the p surcharges.
	 * 
	 * @return the p surcharges
	 */
	public Integer getpSurcharges() {
		return pSurcharges;
	}

	/**
	 * Sets the p surcharges.
	 * 
	 * @param pSurcharges
	 *            the new p surcharges
	 */
	public void setpSurcharges(Integer pSurcharges) {
		this.pSurcharges = pSurcharges;
	}

	/**
	 * Gets the p collected.
	 * 
	 * @return the p collected
	 */
	public Integer getpCollected() {
		return pCollected;
	}

	/**
	 * Sets the p collected.
	 * 
	 * @param pCollected
	 *            the new p collected
	 */
	public void setpCollected(Integer pCollected) {
		this.pCollected = pCollected;
	}

	/**
	 * Gets the p time on.
	 * 
	 * @return the p time on
	 */
	public String getpTimeOn() {
		return pTimeOn;
	}

	/**
	 * Sets the p time on.
	 * 
	 * @param pTimeOn
	 *            the new p time on
	 */
	public void setpTimeOn(String pTimeOn) {
		this.pTimeOn = pTimeOn;
	}

	/**
	 * Gets the user.
	 * 
	 * @return the user
	 */
	public User getUser() {
		return user;
	}

	/**
	 * Sets the user.
	 * 
	 * @param user
	 *            the new user
	 */
	public void setUser(User user) {
		this.user = user;
	}
}