package com.invoicing.entities;

import static javax.persistence.GenerationType.IDENTITY;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

/**
 * The Class User encapsulates model parameters of an Invoice.
 * Contains annotations for integration with Hibernate.
 * 
 * @author Jose Carlos
 */
@Entity
@Table(name = "user", catalog = "invoicing", uniqueConstraints = {
		@UniqueConstraint(columnNames = "NAME"),
		@UniqueConstraint(columnNames = "PASSWORD") })
public class User {

	/** The id. */
	@Id
	@GeneratedValue(strategy = IDENTITY)
	@Column(name = "ID", unique = true, nullable = false)
	private int id;

	/** The name. */
	@Column(name = "NAME", unique = true, nullable = false, length = 20)
	private String name;

	/** The password. */
	@Column(name = "PASSWORD", unique = false, nullable = false, length = 20)
	private String password;

	/** The invoice list. */
	@OneToMany(fetch = FetchType.EAGER, mappedBy = "user")
	private Set<Invoice> invoiceList = new HashSet<Invoice>(0);

	/**
	 * Instantiates a new user.
	 */
	public User() {
	}

	/**
	 * Instantiates a new user.
	 * 
	 * @param name
	 *            the name
	 * @param password
	 *            the password
	 */
	public User(String name, String password) {
		this.name = name;
		this.password = password;
	}

	/**
	 * Instantiates a new user.
	 * 
	 * @param name
	 *            the name
	 * @param password
	 *            the password
	 * @param invoicingList
	 *            the invoicing list
	 */
	public User(String name, String password, Set<Invoice> invoicingList) {
		this.name = name;
		this.password = password;
		this.invoiceList = invoicingList;
	}

	/**
	 * Instantiates a new user.
	 * 
	 * @param id
	 *            the id
	 */
	public User(Integer id) {
		this.id = id;
	}

	/**
	 * Gets the id.
	 * 
	 * @return the id
	 */
	public int getId() {
		return id;
	}

	/**
	 * Sets the id.
	 * 
	 * @param id
	 *            the new id
	 */
	public void setId(int id) {
		this.id = id;
	}

	/**
	 * Gets the name.
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the name.
	 * 
	 * @param name
	 *            the new name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Gets the password.
	 * 
	 * @return the password
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * Sets the password.
	 * 
	 * @param password
	 *            the new password
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Gets the invoice list.
	 * 
	 * @return the invoice list
	 */
	public Set<Invoice> getInvoiceList() {
		return invoiceList;
	}

	/**
	 * Sets the invoice list.
	 * 
	 * @param invoiceList
	 *            the new invoice list
	 */
	public void setInvoiceList(Set<Invoice> invoiceList) {
		this.invoiceList = invoiceList;
	}
}
