package com.invoicing.persistence;

import java.util.Date;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;
import org.springframework.stereotype.Repository;

import com.invoicing.dtos.FilterSearchDTO;
import com.invoicing.entities.Invoice;
import com.invoicing.entities.User;

/**
 * The Class InvoiceDAOImpl implements the invoice model methods.
 * 
 * @author Jose Carlos
 */
@Repository
public class InvoiceDAOImpl extends HibernateDaoSupport implements InvoiceDAOI {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.persistence.InvoiceDAOI#deleteInvoice(com.invoicing.entities
	 * .Invoice)
	 */
	@Override
	public Invoice deleteInvoice(Invoice invoice) throws Exception {
		Session session = getSession();
		try {
			session.beginTransaction();
			invoice = (Invoice) session.get(Invoice.class, invoice.getId());
			session.delete(invoice);
			session.getTransaction().commit();
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		} finally {
			session.close();
		}
		return invoice;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.persistence.InvoiceDAOI#getFilterInvoces(com.invoicing.
	 * dtos.FilterSearchDTO)
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Invoice> getFilterInvoces(FilterSearchDTO filterSearchDTO)
			throws Exception {
		Session session = getSession();
		List<Invoice> invoicesList = null;
		try {
			session.beginTransaction();
			Criteria criteria = session.createCriteria(Invoice.class);
			criteria.add(Restrictions
					.eq("user.id", filterSearchDTO.getUserId()));
			if (filterSearchDTO.getMaxCollected() != null
					&& !filterSearchDTO.getMaxCollected().equalsIgnoreCase("")) {
				criteria.add(Restrictions.le("pCollected", new Integer(
						filterSearchDTO.getMaxCollected())));
			}
			if (filterSearchDTO.getMinCollected() != null
					&& !filterSearchDTO.getMinCollected().equalsIgnoreCase("")) {
				criteria.add(Restrictions.ge("pCollected", new Integer(
						filterSearchDTO.getMinCollected())));
			}
			if (filterSearchDTO.getMaxDate() != null) {
				criteria.add(Restrictions.le("date", filterSearchDTO
						.getMaxDate()));
			}
			if (filterSearchDTO.getMinDate() != null) {
				criteria.add(Restrictions.ge("date", filterSearchDTO
						.getMinDate()));
			}
			if (filterSearchDTO.getMaxSteps() != null
					&& !filterSearchDTO.getMaxSteps().equalsIgnoreCase("")) {
				criteria.add(Restrictions.le("tSteps", new Integer(
						filterSearchDTO.getMaxSteps())));
			}
			if (filterSearchDTO.getMinSteps() != null
					&& !filterSearchDTO.getMinSteps().equalsIgnoreCase("")) {
				criteria.add(Restrictions.ge("tSteps", new Integer(
						filterSearchDTO.getMinSteps())));
			}
			if (filterSearchDTO.getMaxSurcharges() != null
					&& !filterSearchDTO.getMaxSurcharges().equalsIgnoreCase("")) {
				criteria.add(Restrictions.le("pSurcharges", new Integer(
						filterSearchDTO.getMaxSurcharges())));
			}
			if (filterSearchDTO.getMinSurcharges() != null
					&& !filterSearchDTO.getMinSurcharges().equalsIgnoreCase("")) {
				criteria.add(Restrictions.ge("pSurcharges", new Integer(
						filterSearchDTO.getMinSurcharges())));
			}
			invoicesList = criteria.list();
			session.getTransaction().commit();
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		} finally {
			session.close();
		}
		return invoicesList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.persistence.InvoiceDAOI#insertInvoice(com.invoicing.entities
	 * .Invoice)
	 */
	@Override
	public Invoice insertInvoice(Invoice invoice) throws Exception {
		Session session = getSession();
		try {
			session.beginTransaction();
			session.save(invoice);
			session.getTransaction().commit();
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		} finally {
			session.close();
		}
		return invoice;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.persistence.InvoiceDAOI#updateInvoice(com.invoicing.entities
	 * .Invoice)
	 */
	@Override
	public Invoice updateInvoice(Invoice invoice) throws Exception {
		Session session = getSession();
		try {
			session.beginTransaction();
			Invoice invoiceToSave = (Invoice) session.get(Invoice.class,
					invoice.getId());
			invoiceToSave.setDate(invoice.getDate());
			invoiceToSave.setpCollected(invoice.getpCollected());
			invoiceToSave.setpSteps(invoice.getpSteps());
			invoiceToSave.setpSurcharges(invoice.getpSurcharges());
			invoiceToSave.setpTimeOn(invoice.getpTimeOn());
			invoiceToSave.settSteps(invoice.gettSteps());
			session.update(invoiceToSave);
			session.getTransaction().commit();
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		} finally {
			session.close();
		}
		return invoice;
	}

	/**
	 * Proves.
	 */
	public void proves() {

//		System.out.println("Hibernate one to many (Annotation)");
		Session session = getSession();

		session.beginTransaction();
		// InsertUser
		User user = new User("User1", "Pass1");
		session.save(user);
		// UpdateUser
		// Invoice localInvoice = null;
		// User user = (User) session.get(User.class, new Integer(3));
		// for (Invoice sdr : user.getInvoicingList()) {
		// sdr.setSalto(new Float(533));
		// localInvoice = sdr;
		// }
		// user.getInvoicingList().remove(localInvoice);
		// session.delete(localInvoice);

		// Insert invoices;

		// User user = (User) session.get(User.class, new Integer(1));
		Invoice invoice1 = new Invoice();
		invoice1.setDate(new Date());
		invoice1.setpCollected(new Integer(1));
		invoice1.setpSteps(1);
		invoice1.setpTimeOn("12:43");
		invoice1.setpSurcharges(new Integer(1));
		invoice1.settSteps(444);
		invoice1.setUser(user);
		user.getInvoiceList().add(invoice1);
		session.save(invoice1);

		// user = (User) session.get(User.class, new Integer(1));
		// Invoice invoice1 = new Invoice();
		// invoice1.setDate(new Date());
		// invoice1.setUser(user);
		// Invoice invoice2 = new Invoice();
		// Calendar calendar = Calendar.getInstance();
		// calendar.add(Calendar.WEEK_OF_MONTH, 1);
		// Date date = calendar.getTime();
		// invoice2.setDate(date);
		// invoice2.setUser(user);
		// user.getInvoicingList().add(invoice1);
		// user.getInvoicingList().add(invoice2);
		// session.save(invoice1);
		// session.save(invoice2);

		// Stock stock = new Stock();
		// stock.setStockCode("7052");
		// stock.setStockName("PADINI");
		// session.save(stock);

		// StockDailyRecord stockDailyRecords = new StockDailyRecord();
		// stockDailyRecords.setPriceOpen(new Integer("1.2"));
		// stockDailyRecords.setPriceClose(new Integer("1.1"));
		// stockDailyRecords.setPriceChange(new Integer("10.0"));
		// stockDailyRecords.setVolume(3000000L);
		// stockDailyRecords.setDate(new Date());
		// Stock stock = (Stock) session.get(Stock.class, new Integer(1));
		//
		// stockDailyRecords.setStock(stock);
		// stock.getStockDailyRecords().add(stockDailyRecords);
		//
		// session.save(stockDailyRecords);

		// Stock stock = (Stock) session.get(Stock.class, new Integer(1));
		// Query query = null;
		// String HQL = "from StockDailyRecord";
		// query = session.createQuery(HQL);
		// for (StockDailyRecord sdr : stock.getStockDailyRecords()) {
		// session.delete(sdr);
		// }

		// System.out.println(stock.getStockDailyRecords().size());
		session.getTransaction().commit();
//		System.out.println("Done");
		// Query query = null;
		// String HQL = "from User";
		// Session session = getSession();
		// try {
		// query = session.createQuery(HQL);
		// return (List<User>) query.list();
		// } catch (Exception e) {
		// e.printStackTrace();
		// } finally {
		// session.close();
		// }
		// return null;
	}

}
