package com.invoicing.services;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.invoicing.dtos.FilterSearchDTO;
import com.invoicing.dtos.InvoiceDTO;
import com.invoicing.entities.Invoice;
import com.invoicing.entities.User;
import com.invoicing.exceptions.GenericServerException;
import com.invoicing.persistence.InvoiceDAOI;


/**
 * The Class InvoiceServiceImpl implements the invoice business methods.
 * 
 * @author Jose Carlos
 */
@Service
public class InvoiceServiceImpl implements InvoiceServiceI {

	/** The invoice daoi. */
	@Autowired
	private transient InvoiceDAOI invoiceDAOI;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.services.InvoiceServiceI#filterSearch(com.invoicing.dtos
	 * .FilterSearchDTO)
	 */
	@Override
	public List<InvoiceDTO> filterSearch(FilterSearchDTO filterSearchDTO)
			throws GenericServerException {
		List<Invoice> invoiceList = null;
		try {
			invoiceList = invoiceDAOI.getFilterInvoces(filterSearchDTO);
		} catch (Exception e) {
			e.printStackTrace();
			throw new GenericServerException("1", e.getMessage());
		}
		List<InvoiceDTO> invoiceDTOList = new ArrayList<InvoiceDTO>();
		for (Invoice invoice : invoiceList) {
			InvoiceDTO invoiceDTO = new InvoiceDTO();
			invoiceDTO.setDate(invoice.getDate());
			invoiceDTO.setId(invoice.getId());
			invoiceDTO.settSteps(invoice.gettSteps());
			invoiceDTO.setpSteps(invoice.getpSteps());
			invoiceDTO.setpSurcharges(invoice.getpSurcharges());
			invoiceDTO.setpCollected(invoice.getpCollected());
			invoiceDTO.setpTimeOn(invoice.getpTimeOn());
			invoiceDTO.setIdUser(invoice.getUser().getId());
			invoiceDTOList.add(invoiceDTO);
		}
		return invoiceDTOList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.services.InvoiceServiceI#deleteInvoice(com.invoicing.dtos
	 * .InvoiceDTO)
	 */
	@Override
	public InvoiceDTO deleteInvoice(InvoiceDTO invoiceDTO)
			throws GenericServerException {
		User user = new User(invoiceDTO.getIdUser());
		Invoice invoice = new Invoice();
		invoice.setId(invoiceDTO.getId());
		invoice.setUser(user);
		try {
			invoiceDAOI.deleteInvoice(invoice);
		} catch (Exception e) {
			e.printStackTrace();
			throw new GenericServerException("1", e.getMessage());
		}
		return invoiceDTO;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.services.InvoiceServiceI#insertInvoice(com.invoicing.dtos
	 * .InvoiceDTO)
	 */
	@Override
	public InvoiceDTO insertInvoice(InvoiceDTO invoiceDTO)
			throws GenericServerException {
		User user = new User(invoiceDTO.getIdUser());
		Invoice invoice = new Invoice();
		invoice.setDate(invoiceDTO.getDate());
		invoice.setpCollected(invoiceDTO.getpCollected());
		invoice.setpSteps(invoiceDTO.getpSteps());
		invoice.setpSurcharges(invoiceDTO.getpSurcharges());
		invoice.setpTimeOn(invoiceDTO.getpTimeOn());
		invoice.settSteps(invoiceDTO.gettSteps());
		invoice.setUser(user);

		try {
			invoiceDAOI.insertInvoice(invoice);
		} catch (Exception e) {
			e.printStackTrace();
			throw new GenericServerException("1", e.getMessage());
		}
		return invoiceDTO;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.invoicing.services.InvoiceServiceI#updateInvoice(com.invoicing.dtos
	 * .InvoiceDTO)
	 */
	@Override
	public InvoiceDTO updateInvoice(InvoiceDTO invoiceDTO)
			throws GenericServerException {
		Invoice invoice = new Invoice();
		invoice.setId(invoiceDTO.getId());
		invoice.setDate(invoiceDTO.getDate());
		invoice.setpCollected(invoiceDTO.getpCollected());
		invoice.setpSteps(invoiceDTO.getpSteps());
		invoice.setpSurcharges(invoiceDTO.getpSurcharges());
		invoice.setpTimeOn(invoiceDTO.getpTimeOn());
		invoice.settSteps(invoiceDTO.gettSteps());
		User user = new User();
		user.setId(invoiceDTO.getIdUser());
		invoice.setUser(user);
		try {
			invoiceDAOI.updateInvoice(invoice);
		} catch (Exception e) {
			e.printStackTrace();
			throw new GenericServerException("1", e.getMessage());
		}
		return invoiceDTO;

	}

}